==> flutter_boost-0.0.29.tar.gz: lib/router/router.dart <==
import 'dart:async';

import 'package:flutter_boost/container/boost_container.dart';
import 'package:flutter_boost/flutter_boost.dart';
import 'package:flutter_boost/messaging/message_proxy.dart';
import 'package:flutter_boost/messaging/page_result_mediator.dart';
import 'package:flutter_boost/support/logger.dart';

class Router {
  MessageProxy _msgProxy = MessageProxyImp();

  void setMessageProxy(MessageProxy prx) {
    if (prx != null) {
      _msgProxy = prx;
    }
  }

  Future<bool> openPage(String name, Map params, bool animated) {
    return _msgProxy.openPage(name, params, true);
  }

  Future<bool> closePage(
      String name, String pageId, Map params, bool animated) {
    return _msgProxy.closePage(pageId, name, params, animated);
  }

  Future<bool> openUrl(Map params) {
    if (params == null) return Future<bool>((){return false;});

    String url = "";
    if (params.containsKey("url")) {
      url = params["url"] as String;
    }

    bool animated = true;
    if (params.containsKey("animated")) {
      animated = params["animated"] as bool;
    }

    return _msgProxy.openPage(url, params, animated);
  }

  Future<bool> openUrlForResult(Map params , PageResultHandler handler) {
    if (params == null) return Future<bool>((){return false;});

    String url = "";
    if (params.containsKey("url")) {
      url = params["url"] as String;
    }

    bool animated = true;
    if (params.containsKey("animated")) {
      animated = params["animated"] as bool;
    }

    //Add a result mark.
    //Handling page result.
    params["needResult"] = true;
    FlutterBoost.singleton.setPageResultHandler(url, (String key , Map<dynamic,dynamic> result){
      Logger.log("Recieved result $result for from page key $key");
      if(handler != null){
        handler(key,result);
      }
    });

    return _msgProxy.openPage(url, params, animated);
  }


  //Close currentPage page.
  Future<bool> closeCurPage(Map params) {
    final BoostContainerState container = FlutterBoost.containerManager.onstageContainer;

    bool animated = true;
    if (params.containsKey("animated")) {
      animated = params["animated"] as bool;
    }
    return _msgProxy.closePage(container.uniqueId, container.name,
        container.settings.params, animated);
  }

  Future<bool> closePagesByCount(int count) {
    assert(false,'not support');
    return null;
  }

}

==> flutter_boost-0.0.32.tar.gz: lib/router/router.dart <==
import 'dart:async';

import 'package:flutter_boost/container/boost_container.dart';
import 'package:flutter_boost/flutter_boost.dart';
import 'package:flutter_boost/messaging/message_proxy.dart';
import 'package:flutter_boost/messaging/page_result_mediator.dart';
import 'package:flutter_boost/support/logger.dart';

class Router {
  MessageProxy _msgProxy = MessageProxyImp();

  void setMessageProxy(MessageProxy prx) {
    if (prx != null) {
      _msgProxy = prx;
    }
  }

  Future<bool> openPage(String name, Map params, bool animated) {
    return _msgProxy.openPage(name, params, true);
  }

  Future<bool> closePage(
      String name, String pageId, Map params, bool animated) {
    return _msgProxy.closePage(pageId, name, params, animated);
  }

  Future<bool> openUrl(Map params) {
    if (params == null)
      return Future<bool>(() {
        return false;
      });

    String url = "";
    if (params.containsKey("url")) {
      url = params["url"] as String;
    }

    bool animated = true;
    if (params.containsKey("animated")) {
      animated = params["animated"] as bool;
    }

    return _msgProxy.openPage(url, params, animated);
  }

  Future<bool> openUrlForResult(Map params, PageResultHandler handler) {
    if (params == null)
      return Future<bool>(() {
        return false;
      });

    String url = "";
    if (params.containsKey("url")) {
      url = params["url"] as String;
    }

    bool animated = true;
    if (params.containsKey("animated")) {
      animated = params["animated"] as bool;
    }

    //Add a result mark.
    //Handling page result.
    params["needResult"] = true;
    FlutterBoost.singleton.setPageResultHandler(url,
        (String key, Map<dynamic, dynamic> result) {
      Logger.log("Recieved result $result for from page key $key");
      if (handler != null) {
        handler(key, result);
      }
    });

    return _msgProxy.openPage(url, params, animated);
  }

  //Close currentPage page.
  Future<bool> closeCurPage(Map params) {
    BoostContainerSettings settings;

    final BoostContainerState container =
        FlutterBoost.containerManager.onstageContainer;

    if (container != null) {
      settings = container.settings;
    } else {
      settings = FlutterBoost.containerManager.onstageSettings;
    }

    if (settings == null) {
      return Future<bool>(() {
        return false;
      });
    }

    bool animated = true;
    if (params.containsKey("animated")) {
      animated = params["animated"] as bool;
    }

    return _msgProxy.closePage(
        settings.uniqueId, settings.name, settings.params, animated);
  }

  Future<bool> closePagesByCount(int count) {
    assert(false, 'not support');
    return null;
  }
}
